import { Express, Request, Response } from "express";
import { LogLevelDesc, IAsyncProvider } from "@hyperledger/cactus-common";
import { IEndpointAuthzOptions, IExpressRequestHandler, IWebServiceEndpoint } from "@hyperledger/cactus-core-api";
import { PluginLedgerConnectorStub } from "../plugin-ledger-connector-stub";
export interface IUnprotectedActionEndpointOptions {
    logLevel?: LogLevelDesc;
    connector: PluginLedgerConnectorStub;
}
/**
 * The purpose of this endpoint class is to provide integration tests with a
 * way to verify if the checks in place for unprotected endpints are working
 * as intended.
 */
export declare class UnprotectedActionEndpoint implements IWebServiceEndpoint {
    readonly options: IUnprotectedActionEndpointOptions;
    static readonly CLASS_NAME = "UnprotectedActionEndpoint";
    static readonly OAUTH2_SCOPES: never[];
    private readonly log;
    get className(): string;
    constructor(options: IUnprotectedActionEndpointOptions);
    getOasPath(): {
        post: {
            operationId: string;
            "x-hyperledger-cactus": {
                http: {
                    path: string;
                    verbLowerCase: string;
                };
            };
        };
    };
    getPath(): string;
    getVerbLowerCase(): string;
    getOperationId(): string;
    getAuthorizationOptionsProvider(): IAsyncProvider<IEndpointAuthzOptions>;
    registerExpress(expressApp: Express): Promise<IWebServiceEndpoint>;
    getExpressRequestHandler(): IExpressRequestHandler;
    handleRequest(req: Request, res: Response): Promise<void>;
}
